<?php

namespace Litecms\OurServices\Providers;

use Illuminate\Support\ServiceProvider;

class OurServicesServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'our_services');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'our_services');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.our_services', function ($app) {
            return $this->app->make('Litecms\OurServices\OurServices');
        });

                // Bind OurService to repository
        $this->app->bind(
            'Litecms\OurServices\Interfaces\OurServiceRepositoryInterface',
            \Litecms\OurServices\Repositories\Eloquent\OurServiceRepository::class
        );

        $this->app->register(\Litecms\OurServices\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\OurServices\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.our_services'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/our_services.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/our_services')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/our_services')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
